<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=nb
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Gjenopprett databasen',

	// I
	'info_restauration_sauvegarde' => 'gjenopprettet sikkerhetskopien @archive@', # MODIF
	'info_sauvegarde' => 'Ta sikkerhetskopi',
	'info_sauvegarde_reussi_02' => 'Databasen er lagret i @archive@. Du kan', # MODIF
	'info_sauvegarde_reussi_03' => 'gå tilbake til administrasjonsgrensesnittet',
	'info_sauvegarde_reussi_04' => 'av nettstedet ditt.',

	// T
	'texte_admin_tech_02' => 'Attention: cette sauvegarde ne pourra être restaurée QUE dans un site installé sous la même version de SPIP. Il ne faut donc surtout pas « vider la base » en espérant réinstaller la sauvegarde après une mise à jour... Consultez <a href="@spipnet@">la documentation de SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Gjenopprett innholdet av databasens sikkerhetskopi',
	'texte_sauvegarde' => 'Ta sikkerhetskopi av databaseinnholdet',
	'texte_sauvegarde_base' => 'Ta sikkerhetskopi av databasen',
];
